==> vradi-entities-0.3.1-sources.jar: com/jurismarches/vradi/entities/XmlStreamAbstract.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public  abstract class XmlStreamAbstract extends BusinessEntityWikitty implements XmlStream {

    public static final List<WikittyExtension> extensions;
    public static final WikittyExtension extensionXmlStream;
    /**
     * getUrl :
     * @return String 
     */

    @Override
    public String getUrl() {
        String value = XmlStreamHelper.getUrl(getWikitty());
        return value;
}

    /**
     * setUrl :
     * @param url 
     */

    @Override
    public void setUrl(String url) {
        String oldValue = getUrl();
        XmlStreamHelper.setUrl(getWikitty(), url);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_URL, oldValue, getUrl());
}

    /**
     * getName :
     * @return String 
     */

    @Override
    public String getName() {
        String value = XmlStreamHelper.getName(getWikitty());
        return value;
}

    /**
     * setName :
     * @param name 
     */

    @Override
    public void setName(String name) {
        String oldValue = getName();
        XmlStreamHelper.setName(getWikitty(), name);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_NAME, oldValue, getName());
}

    /**
     * getFormTypeName :
     * @return String 
     */

    @Override
    public String getFormTypeName() {
        String value = XmlStreamHelper.getFormTypeName(getWikitty());
        return value;
}

    /**
     * setFormTypeName :
     * @param formTypeName 
     */

    @Override
    public void setFormTypeName(String formTypeName) {
        String oldValue = getFormTypeName();
        XmlStreamHelper.setFormTypeName(getWikitty(), formTypeName);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_FORMTYPENAME, oldValue, getFormTypeName());
}

    /**
     * getImportTime :
     * @return String 
     */

    @Override
    public String getImportTime() {
        String value = XmlStreamHelper.getImportTime(getWikitty());
        return value;
}

    /**
     * setImportTime :
     * @param importTime 
     */

    @Override
    public void setImportTime(String importTime) {
        String oldValue = getImportTime();
        XmlStreamHelper.setImportTime(getWikitty(), importTime);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_IMPORTTIME, oldValue, getImportTime());
}

    /**
     * getXmlFieldBinding :
     * @return Set<String> 
     */

    @Override
    public Set<String> getXmlFieldBinding() {
        Set<String> result = XmlStreamHelper.getXmlFieldBinding(getWikitty());
        return result;
}

    /**
     * addXmlFieldBinding :
     * @param element 
     */

    @Override
    public void addXmlFieldBinding(String element) {
        XmlStreamHelper.addXmlFieldBinding(getWikitty(), element);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, null, getXmlFieldBinding());
}

    /**
     * removeXmlFieldBinding :
     * @param element 
     */

    @Override
    public void removeXmlFieldBinding(String element) {
        XmlStreamHelper.removeXmlFieldBinding(getWikitty(), element);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, null, getXmlFieldBinding());
}

    /**
     * clearXmlFieldBinding :
     */

    @Override
    public void clearXmlFieldBinding() {
        XmlStreamHelper.clearXmlFieldBinding(getWikitty());
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, null, getXmlFieldBinding());
}

    /**
     * XmlStreamAbstract :
     */

    public XmlStreamAbstract() {
        super();
}

    /**
     * XmlStreamAbstract :
     * @param wikitty 
     */

    public XmlStreamAbstract(Wikitty wikitty) {
        super(wikitty);
}

    /**
     * XmlStreamAbstract :
     * @param businessEntityWikitty 
     */

    public XmlStreamAbstract(BusinessEntityWikitty businessEntityWikitty) {
        super(businessEntityWikitty.getWikitty());
}

    /**
     * getStaticExtensions :
     * @return Collection<WikittyExtension> 
     */

    @Override
    public Collection<WikittyExtension> getStaticExtensions() {
        return extensions;
}

static {
    
        extensionXmlStream =
                new WikittyExtension(EXT_XMLSTREAM,
                                     "5.0", // version
                                     null,
                                     WikittyUtil.buildFieldMapExtension( // building field map
                                             "String url unique=true", 
                                             "String name unique=true", 
                                             "String formTypeName unique=true", 
                                             "String importTime unique=true documentation=\"Heure d'import des flux.\"", 
                                             "Wikitty xmlFieldBinding[0-*] unique=true"));

        // init extensions
        List<WikittyExtension> exts = new ArrayList<WikittyExtension>();

        exts.add(extensionXmlStream);
        extensions = Collections.unmodifiableList(exts);

    }
    /**
     * toString :
     * @return String 
     */

    @Override
    public String toString() {
        return getWikitty().toString();
}


} //XmlStreamAbstract

==> vradi-entities-0.5.1-sources.jar: com/jurismarches/vradi/entities/XmlStreamAbstract.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;


public  abstract class XmlStreamAbstract extends BusinessEntityImpl implements XmlStream {

    public static final List<WikittyExtension> extensions;
    public static final WikittyExtension extensionXmlStream;
    /**
     * getUrl :
     * @return String 
     */

    @Override
    public String getUrl() {
        String value = XmlStreamHelper.getUrl(getWikitty());
        return value;
}

    /**
     * setUrl :
     * @param url 
     */

    @Override
    public void setUrl(String url) {
        String oldValue = getUrl();
        XmlStreamHelper.setUrl(getWikitty(), url);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_URL, oldValue, getUrl());
}

    /**
     * getName :
     * @return String 
     */

    @Override
    public String getName() {
        String value = XmlStreamHelper.getName(getWikitty());
        return value;
}

    /**
     * setName :
     * @param name 
     */

    @Override
    public void setName(String name) {
        String oldValue = getName();
        XmlStreamHelper.setName(getWikitty(), name);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_NAME, oldValue, getName());
}

    /**
     * getFormTypeName :
     * @return String 
     */

    @Override
    public String getFormTypeName() {
        String value = XmlStreamHelper.getFormTypeName(getWikitty());
        return value;
}

    /**
     * setFormTypeName :
     * @param formTypeName 
     */

    @Override
    public void setFormTypeName(String formTypeName) {
        String oldValue = getFormTypeName();
        XmlStreamHelper.setFormTypeName(getWikitty(), formTypeName);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_FORMTYPENAME, oldValue, getFormTypeName());
}

    /**
     * getImportTime :
     * @return String 
     */

    @Override
    public String getImportTime() {
        String value = XmlStreamHelper.getImportTime(getWikitty());
        return value;
}

    /**
     * setImportTime :
     * @param importTime 
     */

    @Override
    public void setImportTime(String importTime) {
        String oldValue = getImportTime();
        XmlStreamHelper.setImportTime(getWikitty(), importTime);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_IMPORTTIME, oldValue, getImportTime());
}

    /**
     * getXmlFieldBinding :
     * @return Set<String> 
     */

    @Override
    public Set<String> getXmlFieldBinding() {
        Set<String> result = XmlStreamHelper.getXmlFieldBinding(getWikitty());
        return result;
}

    /**
     * setXmlFieldBinding :
     * @param xmlFieldBinding 
     */

    @Override
    public void setXmlFieldBinding(Set<String> xmlFieldBinding) {
        Set<String> oldValue = getXmlFieldBinding();
        XmlStreamHelper.setXmlFieldBinding(getWikitty(), xmlFieldBinding);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, oldValue, getXmlFieldBinding());
}

    /**
     * addAllXmlFieldBinding :
     * @param xmlFieldBinding 
     */

    @Override
    public void addAllXmlFieldBinding(Set<String> xmlFieldBinding) {
        Set<String> oldValue = getXmlFieldBinding();
        XmlStreamHelper.addAllXmlFieldBinding(getWikitty(), xmlFieldBinding);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, oldValue, getXmlFieldBinding());
}

    /**
     * addXmlFieldBinding :
     * @param element 
     */

    @Override
    public void addXmlFieldBinding(String element) {
        XmlStreamHelper.addXmlFieldBinding(getWikitty(), element);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, null, getXmlFieldBinding());
}

    /**
     * removeXmlFieldBinding :
     * @param element 
     */

    @Override
    public void removeXmlFieldBinding(String element) {
        XmlStreamHelper.removeXmlFieldBinding(getWikitty(), element);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, null, getXmlFieldBinding());
}

    /**
     * clearXmlFieldBinding :
     */

    @Override
    public void clearXmlFieldBinding() {
        XmlStreamHelper.clearXmlFieldBinding(getWikitty());
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, null, getXmlFieldBinding());
}

    /**
     * XmlStreamAbstract :
     */

    public XmlStreamAbstract() {
        super();
}

    /**
     * XmlStreamAbstract :
     * @param wikitty 
     */

    public XmlStreamAbstract(Wikitty wikitty) {
        super(wikitty);
}

    /**
     * XmlStreamAbstract :
     * @param businessEntityImpl 
     */

    public XmlStreamAbstract(BusinessEntityImpl businessEntityImpl) {
        super(businessEntityImpl.getWikitty());
}

    /**
     * getStaticExtensions :
     * @return Collection<WikittyExtension> 
     */

    @Override
    public Collection<WikittyExtension> getStaticExtensions() {
        return extensions;
}

static {
    
        extensionXmlStream =
                new WikittyExtension(EXT_XMLSTREAM,
                                     "5.0", // version
                                     null,
                                     WikittyUtil.buildFieldMapExtension( // building field map
                                             "String url unique=\"true\"", 
                                             "String name unique=\"true\"", 
                                             "String formTypeName unique=\"true\"", 
                                             "String importTime unique=\"true\" documentation=\"Heure d'import des flux.\"", 
                                             "Wikitty xmlFieldBinding[0-*] unique=\"true\""));

        // init extensions
        List<WikittyExtension> exts = new ArrayList<WikittyExtension>();

        exts.add(extensionXmlStream);
        extensions = Collections.unmodifiableList(exts);

    }
    /**
     * toString :
     * @return String 
     */

    @Override
    public String toString() {
        return getWikitty().toString();
}


} //XmlStreamAbstract
